<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Furniture;
use App\Models\User;
use App\Models\Business;
use App\Models\Product;
use App\Models\Branding;
use App\Models\Contractor;
use App\Models\Power;
use App\Models\Media;
use Illuminate\Support\Facades\Storage;
use App\Models\Tax;
use App\Models\Advertisement;
use App\Models\Page;
use App\Models\BadgeLimit;
use Illuminate\Support\Facades\View;
use Illuminate\Support\Facades\File;
use App\Traits\ViewPathTrait;
class MasterController extends Controller
{
    use ViewPathTrait;
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index($module)
    {
            // Define the directory path
        $directoryPath = resource_path('views/admin/masters/' . $module);

        // Check if the directory exists, if not, create it
        if (!File::isDirectory($directoryPath)) {
            File::makeDirectory($directoryPath, 0755, true, true);
        }

        // Define the view file path
        $viewPath = $directoryPath . '/index.blade.php';

        // Check if the view file exists
        if (!File::exists($viewPath)) {
            // If the view doesn't exist, create it
            $this->createMasterIndexView($viewPath, $module);
        }
        $menuItems = json_decode(File::get(storage_path(auth()->user()->role . '_menu.json')), true);
        $taxes = [];
        switch ($module) {
            case 'furniture':
                $arr = Furniture::getAllFurnitures();                              
            break;
            case 'business':
                $arr = Business::getAllBusiness();                
            break;
            case 'products':
                $arr = Product::getAllProducts();                
            break;
            case 'branding':
                $arr = Branding::getAllBranding();
            break;
            case 'contractors':
                $arr = Contractor::getAllContractors();
            break;
            case 'power':
                $arr = Power::getAllPowers();
                break;
            case 'advertisement':
                $arr = Advertisement::getAllAdvertisements();
            break;
            case 'boothdesign':
                $arr = Media::getFirstBoothDesign('booth');
            break;
            case 'medias':
                $arr = Media::getFirstBoothDesign('media');
            break;
            case 'map':
                $arr = Media::getFirstBoothDesign('map');
            break;
            case 'exhibitor-content':
                $arr = Page::getFirstContent('exhibitor-dashboard-instructions');
            break;
            case 'badge-limits':
                $arr = BadgeLimit::getAllData('badges-limit');
            break;
            case 'taxes':
                $taxes = [
                    'cgst' => 'cgst',
                    'sgst' => 'sgst',
                    'igst' => 'igst',
                ];
                $arr = Tax::getAllData('taxes');
            break;
            default:
                $arr  = [];
                break;
        }
        return view('admin.masters.' . $module . '.index',compact('menuItems','arr','taxes'));
    }
    public function fetchData(Request $request)
    {
        // Retrieve data from the server or database
        // Example data for demonstration
        $data = [
            ['name' => 'Name 1', 'description' => 'Description 1', 'value' => 'Value 1'],
            ['name' => 'Name 2', 'description' => 'Description 2', 'value' => 'Value 2'],
            // Add more data as needed
        ];
    
        return response()->json([
            'data' => $data
        ]);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $model = $request->input('model');
        switch ($model) {
            case 'furniture':
                $saveData = Furniture::FurnitureSaveData($request);
                return $saveData;
            break;
            case 'business':
                $saveData = Business::BusinessSaveData($request);
                return $saveData;
            break;
            case 'products':
                $saveData = Product::ProductSaveData($request);
                return $saveData;
            break;
            case 'branding':
                $request->validate([
                    // 'image' => 'required|image|mimes:jpeg,png,jpg,gif|max:2048',
                    'image' => 'required',
                ]);
                if ($request->hasFile('image')) {
                    $image = $request->file('image');
                    $imageName = time() . '.' . $image->getClientOriginalExtension();
        
                    // Check if the directory exists, create it if not
                    if (!Storage::exists('public/branding')) {
                        Storage::makeDirectory('public/branding');
                    }
                    // Store the image in the branding directory
                    $imagePath = $image->storeAs('public/branding', $imageName);
                    $imageUrl = str_replace('public/', '', $imagePath);
                    Branding::create([
                        'image' => $imageUrl,
                        'name' => $request->input('name'),
                        'width' => $request->input('width'),
                        'height' => $request->input('height'),
                        'area' => $request->input('total_area'),
                        'price' => $request->input('fixed_price'),
                        'total' => $request->input('total_price'),
                    ]);
                    return back()->with('success', 'Record Added successfully.');
                }
                return back()->with('error', 'Failed to upload image.');
            break;
            case 'contractors':
                $saveData = Contractor::ContractorSaveData($request);
                return $saveData;
            break;
            case 'power':
            $saveData = Power::PowerSaveData($request);
            return $saveData;
            break;
            case 'advertisement':
                $saveData = Advertisement::AdvertisementSaveData($request);
            return $saveData;
            break;
            case 'boothdesign':
                $saveData = Media::boothSave($request,'booth');
            return $saveData;
            break;
            case 'map':
                $saveData = Media::boothSave($request,'map');
            return $saveData;
            case 'medias':
                $saveData = Media::boothSave($request,'media');
            return $saveData;
            break;
            case 'exhibitor-dashboard-instructions':
                $saveData = Page::contentSave($request,'exhibitor-dashboard-instructions');
            return $saveData;
            break;
            case 'badge-limits':
                $saveData = BadgeLimit::contentSave($request,'badges-limit');
            return $saveData;
            break;
            case 'taxes':
                $saveData = Tax::TaxSaveData($request,'taxes');
            return $saveData;
            break;
            default:
                # code...
                break;
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {   

    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request)
    {
        $model = $request->input('model');
        $id = $request->input('id');
        switch ($model) {
            case 'furniture':
                $record = Furniture::updateById($request);
            break;
            case 'business':
                $record = Business::updateById($request);
            break;
            case 'products':
                $record = Product::updateById($request);
            break;
            case 'branding':
                $record = Branding::updateById($request);
                break;
            case 'contractor':
                $record = Contractor::updateById($request);
            break;
            case 'power':
                $record = Power::updateById($request);
            break;
            case 'advertisement':
                $record = Advertisement::updateById($request);
            break;
            case 'booth':
                $record = Media::updateById($request,'booth');
            break;
            case 'media':
                $record = Media::updateById($request,'media');
            break;
            case 'map':
                $record = Media::updateById($request,'map');
            break;
            case 'exhibitor-dashboard-instructions':
                $record = Page::updateById($request,'exhibitor-dashboard-instructions');
            break;
            case 'badge-limits':
                $record = BadgeLimit::updateById($request,'badges-limit');
            break;
            case 'taxes':
                $record = Tax::updateById($request,'taxes');
            break;
            default:
                # code...
            break;
        }
        return $record;
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $model = $request->input('model');
        $id = $request->input('id');
        $record = User::deleteById($id, $model);
        return $record;
    }
}
