<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;
use App\Models\Furniture;
use App\Models\Business;
use App\Models\Product;
use App\Models\Branding;
use App\Models\Contractor;
use App\Models\Power;
use App\Models\Media;
use App\Models\Tax;
use App\Models\Advertisement;
use App\Models\Page;
use App\Models\BadgeLimit;
use App\Models\Exhibitor;
use App\Models\Setting;
use Illuminate\Support\Collection;

class HomeController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function index()
    {
        if(auth()->user()->role == 'admin'){
            return redirect()->route('admin-home');
        }else if(auth()->user()->role == 'exhibitor'){
            return redirect()->route('exhibitor-home');
        }else{
            return redirect()->route('home');
        }
    }
    public function adminDashboard()
    {        
        $menuItems = json_decode(File::get(storage_path(auth()->user()->role . '_menu.json')), true);
        $arr = [
            'furniture' => Furniture::getAllFurnitures(),
            'business' => Business::getAllBusiness(),
            'branding' => Branding::getAllBranding(),
            'contractors' => Contractor::getAllContractors(),
            'power' => Power::getAllPowers(),
            'advertisement' => Advertisement::getAllAdvertisements(),
            'booth-design' => Media::getFirstBoothDesign('booth'),
            'map' => Media::getFirstBoothDesign('map'),
            'exhibitor-schedule-content' => Page::getFirstContent('exhibitor-content'),
            'badge-limits' => BadgeLimit::getAllData('badges-limit'),
            'products' => Product::getAllProducts(),
            'taxes' => Tax::getAllData('taxes'),
            'exhibition-venue' => Setting::getData('exhibition-venue'),
            'basic-details' => Setting::getData('basic-details'),
            'website-logo' => Setting::getData('website-logo'),
            'badge-series' => Setting::getData('badge-series'),
            'badge-image' => Setting::getData('badge-image'),
            'otp-settings' => Setting::getData('otp-settings'),            
        ];
        $master = [];
        foreach($arr as $key => $modules){
            if($key == 'booth-design' || $key == 'map' || $key == 'exhibition-venue'){
                $master[] = [
                    'name' => strtoupper($key),
                    'status' => gettype($modules) == 'object' ? true : false
                ];
            }else{
                $master[] = [
                    'name' => strtoupper($key),
                    'status' => $modules instanceof Collection
                ];
            }
        }
        return view('admin-home', ['menuItems' => $menuItems,'master' => $master]);
    }
    public function exhibitorDashboard()
    {
        $instructions = Page::getFirstContent('exhibitor-dashboard-instructions');
        $menuItems = json_decode(File::get(storage_path(auth()->user()->role . '_menu.json')), true);
        return view('exhibitor-home',['menuItems' => $menuItems,'instructions' => $instructions]);
    }
    public function exhibitorDetails(){
        $menuItems = json_decode(File::get(storage_path(auth()->user()->role . '_menu.json')), true);
        $exhibitor = Exhibitor::where('id',auth()->user()->id)->first();
        return view ('exhibitor.details',compact('exhibitor','menuItems'));
    }
}
