<?php

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', function () {
    $arr = [
        'venueDetails' => App\Models\Setting::where('meta_key', 'exhibition-venue')->first(),
    ];
    return view ('frontend.home',compact('arr'));
});

Route::get('/home', [App\Http\Controllers\HomeController::class, 'index'])->name('home');
Auth::routes();
Route::group([
    'prefix' => 'admin/home',
    'middleware' => 'is_admin'
], function() {
    // Admin Routes
    Route::get('/', [App\Http\Controllers\HomeController::class, 'adminDashboard'])->name('admin-home');
        // Master Routes
    Route::prefix('masters')->name('masters.')->group(function () {
        Route::resource('{module}/', App\Http\Controllers\Admin\MasterController::class);
        Route::post('{module}/destroy', [App\Http\Controllers\Admin\MasterController::class, 'destroy']);
        Route::post('{module}/update', [App\Http\Controllers\Admin\MasterController::class, 'update']);
    });
    // Settings Routes
    Route::prefix('settings')->name('settings.')->group(function () {
        Route::resource('{module}/', App\Http\Controllers\Admin\SettingController::class);
        Route::post('{module}/update', [App\Http\Controllers\Admin\SettingController::class, 'update']);
        Route::post('{module}/destroy', [App\Http\Controllers\Admin\SettingController::class, 'destroy']);
    });
    // Stall Management Routes
    Route::prefix('stall-management')->name('stall-management.')->group(function () {
        Route::resource('{module}/', App\Http\Controllers\Admin\StallManagementController::class);
        Route::post('{module}/update', [App\Http\Controllers\Admin\StallManagementController::class, 'update']);
        Route::post('{module}/destroy', [App\Http\Controllers\Admin\StallManagementController::class, 'destroy']);
    });
    // Email Management Routes
    Route::prefix('email-management')->name('email-management.')->group(function () {
        Route::resource('{module}/', App\Http\Controllers\Admin\EmailManagementController::class);
        Route::post('{module}/update', [App\Http\Controllers\Admin\EmailManagementController::class, 'update']);
        Route::post('{module}/destroy', [App\Http\Controllers\Admin\EmailManagementController::class, 'destroy']);
    });
    // User Management Routes
    Route::prefix('users')->name('users.')->group(function () {
        Route::resource('{module}/', App\Http\Controllers\Admin\UserManagementController::class);
        Route::post('{module}/update', [App\Http\Controllers\Admin\UserManagementController::class, 'update']);
        Route::post('{module}/destroy', [App\Http\Controllers\Admin\UserManagementController::class, 'destroy']);
        Route::post('{module}/generate-otp', [App\Http\Controllers\Admin\UserManagementController::class, 'generateOTP']);
        Route::post('{module}/verify-otp', [App\Http\Controllers\Admin\UserManagementController::class, 'verifyOTP']);
    });
    // Exhibitor
    Route::prefix('exhibitors')->name('exhibitors.')->group(function () {
        Route::get('list/', [App\Http\Controllers\Admin\UserManagementController::class, 'exhibitorList']);
        Route::get('list/{id}', [App\Http\Controllers\Admin\UserManagementController::class, 'exhibitorDetail']);
        Route::get('{id}/edit', [App\Http\Controllers\Admin\UserManagementController::class, 'exhibitorEdit']);
        Route::delete('{id}', [App\Http\Controllers\Admin\UserManagementController::class, 'deleteExhibitor'])->name('destroy');
        Route::put('{id}', [App\Http\Controllers\Admin\UserManagementController::class, 'updateExhibitor']);
        Route::get('create/', [App\Http\Controllers\Admin\UserManagementController::class, 'AddExhibitor']);
        Route::post('new', [App\Http\Controllers\Admin\UserManagementController::class, 'storeExhibitor']);        
        // Route::post('{module}/update', [App\Http\Controllers\Admin\UserManagementController::class, 'update']);
        // Route::post('{module}/destroy', [App\Http\Controllers\Admin\UserManagementController::class, 'destroy']);
        // Route::post('{module}/generate-otp', [App\Http\Controllers\Admin\UserManagementController::class, 'generateOTP']);
        // Route::post('{module}/verify-otp', [App\Http\Controllers\Admin\UserManagementController::class, 'verifyOTP']);
    });
});
// Exhibitor Routes
Route::group([
    'prefix' => 'exhibitor/home',
    'middleware' => 'is_exhibitor'
], function() {
    Route::get('/', [App\Http\Controllers\HomeController::class, 'exhibitorDashboard'])->name('exhibitor-home');
    Route::get('/details', [App\Http\Controllers\HomeController::class, 'exhibitorDetails'])->name('exhibitor-home');
    // Requirements
    Route::prefix('requirements')->name('requirements.')->group(function () {
        Route::get('{module}/', [App\Http\Controllers\Exhibitor\RequirementController::class, 'getRequirement']);
    });
});
